const { Gio, GObject } = imports.gi;
const { panelMenu } = imports.ui;
const Me = imports.misc.extensionUtils.getCurrentExtension();
const Resources = Me.imports.modules.resources;
const Log = Me.imports.modules.log;
const PROFILE_ICONS = {
    'performance': 'power-profile-performance-symbolic',
    'balanced': 'power-profile-balanced-symbolic',
    'power-saver': 'power-profile-power-saver-symbolic',
};
var powerProfileIndicator = GObject.registerClass(class powerProfileIndicator extends panelMenu.SystemIndicator {
    constructor() {
        super(...arguments);
        this.powerProfilesProxy = null;
        this.powerProfilesSignalProxy = null;
        this.connected = false;
        this._state = '';
        this.profiles = [];
    }
    _init() {
        super._init();
        try {
            this._indicator = this._addIndicator();
            this._indicator.icon_name = 'power-profile-balanced-symbolic';
            this._indicator.visible = true;
            this.createProxy();
        }
        catch (error) {
            Log.raw('init failed', error);
        }
    }
    createProxy() {
        this.connected = true;
        let xmlProfiles = Resources.File.DBus('net.hadess.PowerProfiles-0.10.1');
        this.powerProfilesProxy = new Gio.DBusProxy.makeProxyWrapper(xmlProfiles)(Gio.DBus.system, 'net.hadess.PowerProfiles', '/net/hadess/PowerProfiles');
        let xmlSignals = Resources.File.DBus('net.hadess.PowerProfilesSignals-0.10.1');
        this.powerProfilesSignalProxy = new Gio.DBusProxy.makeProxyWrapper(xmlSignals)(Gio.DBus.system, 'org.freedesktop.DBus.Properties', '/net/hadess/PowerProfiles');
        this.getProfileNames();
        this._state = this.powerProfilesProxy.ActiveProfile;
        this.updateProfile();
        this.powerProfilesSignalProxy.connectSignal("PropertiesChanged", (name = '', variant, profile) => {
            this.setProfileFromSignal(name, variant, profile);
        });
    }
    getProfileNames() {
        if (!this.connected)
            this.createProxy();
        if (this.connected) {
            try {
                let _profiles = this.powerProfilesProxy.Profiles;
                if (_profiles.length > 0) {
                    this.profiles = [];
                    for (const [_key, value] of Object.entries(_profiles)) {
                        this.profiles[parseInt(_key)] = {
                            'Profile': value.Profile.unpack(),
                            'Driver': value.Driver.unpack()
                        };
                    }
                }
            }
            catch (e) {
                Log.raw(`Power Profiles: failed to fetch profile names!`, e);
            }
        }
        return this.profiles;
    }
    setProfileFromSignal(name = '', variant, profile = []) {
        if (!this.connected)
            this.createProxy();
        Log.raw(this.connected);
        if (this.connected) {
            try {
                if (profile.length > 0) {
                    for (const [_key, value] of Object.entries(profile)) {
                        if (typeof value == 'object') {
                            for (const [_keyInner, valueInner] of Object.entries(value)) {
                                if (_keyInner == 'ActiveProfile') {
                                    let currentProfile = valueInner.print(true);
                                    currentProfile = currentProfile.replaceAll("'", '');
                                    this._state = currentProfile;
                                    this.updateProfile();
                                    return true;
                                }
                            }
                        }
                    }
                }
            }
            catch (e) {
                Log.raw(`Power Profiles: failed to fetch profile names!`, e);
                return false;
            }
        }
    }
    updateProfile() {
        if (!(this._state.length > 0) || !this.connected) {
            this.indicator.visible = false;
            return false;
        }
        this._indicator.icon_name = PROFILE_ICONS[this._state];
        return true;
    }
    stop() {
        if (this.connected) {
            this.connected = false;
            this.powerProfilesProxy = null;
            this.powerProfilesSignalProxy = null;
        }
    }
});
//# sourceMappingURL=panel.js.map